import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.mercury_assessment import MercuryAssessment
from ..types import UNSET, Unset

T = TypeVar("T", bound="MercuryResult")


@attr.s(auto_attribs=True)
class MercuryResult:
    """  """

    assessment: MercuryAssessment
    create_date: datetime.datetime
    description: Union[Unset, str] = UNSET
    score: Union[Unset, float] = UNSET
    band: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        assessment = self.assessment.to_dict()

        create_date = self.create_date.isoformat()

        description = self.description
        score = self.score
        band = self.band

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {"assessment": assessment, "create_date": create_date,}
        )
        if description is not UNSET:
            field_dict["description"] = description
        if score is not UNSET:
            field_dict["score"] = score
        if band is not UNSET:
            field_dict["band"] = band

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        assessment = MercuryAssessment.from_dict(d.pop("assessment"))

        create_date = isoparse(d.pop("create_date"))

        description = d.pop("description", UNSET)

        score = d.pop("score", UNSET)

        band = d.pop("band", UNSET)

        mercury_result = cls(
            assessment=assessment, create_date=create_date, description=description, score=score, band=band,
        )

        mercury_result.additional_properties = d
        return mercury_result

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar

import attr
from dateutil.parser import isoparse

T = TypeVar("T", bound="MercuryReport")


@attr.s(auto_attribs=True)
class MercuryReport:
    """  """

    download_url: str
    create_date: datetime.datetime
    modify_date: datetime.datetime
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        download_url = self.download_url
        create_date = self.create_date.isoformat()

        modify_date = self.modify_date.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {"download_url": download_url, "create_date": create_date, "modify_date": modify_date,}
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        download_url = d.pop("download_url")

        create_date = isoparse(d.pop("create_date"))

        modify_date = isoparse(d.pop("modify_date"))

        mercury_report = cls(download_url=download_url, create_date=create_date, modify_date=modify_date,)

        mercury_report.additional_properties = d
        return mercury_report

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="MercuryListOrdersRequest")


@attr.s(auto_attribs=True)
class MercuryListOrdersRequest:
    """  """

    job_application_id: Union[Unset, str] = UNSET
    candidate_id: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        job_application_id = self.job_application_id
        candidate_id = self.candidate_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if job_application_id is not UNSET:
            field_dict["job_application_id"] = job_application_id
        if candidate_id is not UNSET:
            field_dict["candidate_id"] = candidate_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        job_application_id = d.pop("job_application_id", UNSET)

        candidate_id = d.pop("candidate_id", UNSET)

        mercury_list_orders_request = cls(job_application_id=job_application_id, candidate_id=candidate_id,)

        mercury_list_orders_request.additional_properties = d
        return mercury_list_orders_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.mercury_error_response import MercuryErrorResponse
from ...models.o_auth_token_request import OAuthTokenRequest
from ...models.o_auth_token_response import OAuthTokenResponse
from ...types import Response


def _get_kwargs(*, client: Client, json_body: OAuthTokenRequest,) -> Dict[str, Any]:
    url = "{}/mercury/oauth/token".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[MercuryErrorResponse, OAuthTokenResponse]]:
    if response.status_code == 201:
        response_201 = OAuthTokenResponse.from_dict(response.json())

        return response_201
    if response.status_code == 400:
        response_400 = MercuryErrorResponse.from_dict(response.json())

        return response_400
    if response.status_code == 401:
        response_401 = MercuryErrorResponse.from_dict(response.json())

        return response_401
    if response.status_code == 500:
        response_500 = MercuryErrorResponse.from_dict(response.json())

        return response_500
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[MercuryErrorResponse, OAuthTokenResponse]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *, client: Client, json_body: OAuthTokenRequest,
) -> Response[Union[MercuryErrorResponse, OAuthTokenResponse]]:
    kwargs = _get_kwargs(client=client, json_body=json_body,)

    response = httpx.post(verify=client.verify_ssl, **kwargs,)

    return _build_response(response=response)


def sync(*, client: Client, json_body: OAuthTokenRequest,) -> Optional[Union[MercuryErrorResponse, OAuthTokenResponse]]:
    """ The response's bearer token must be used in the `Authorization` header for any other API request. Tokens are valid for only a period of time.

All requests, with the exception of this one, also require an API Key to be supplied in the `X-Api-Key` request header.
pymetrics will supply this along with the OAuth Client ID and Secret.
 """

    return sync_detailed(client=client, json_body=json_body,).parsed


async def asyncio_detailed(
    *, client: Client, json_body: OAuthTokenRequest,
) -> Response[Union[MercuryErrorResponse, OAuthTokenResponse]]:
    kwargs = _get_kwargs(client=client, json_body=json_body,)

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *, client: Client, json_body: OAuthTokenRequest,
) -> Optional[Union[MercuryErrorResponse, OAuthTokenResponse]]:
    """ The response's bearer token must be used in the `Authorization` header for any other API request. Tokens are valid for only a period of time.

All requests, with the exception of this one, also require an API Key to be supplied in the `X-Api-Key` request header.
pymetrics will supply this along with the OAuth Client ID and Secret.
 """

    return (await asyncio_detailed(client=client, json_body=json_body,)).parsed



from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.mercury_error_response import MercuryErrorResponse
from ...models.mercury_list_orders_request import MercuryListOrdersRequest
from ...models.mercury_list_orders_response import MercuryListOrdersResponse
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    json_body: MercuryListOrdersRequest,
    authorization: Union[Unset, str] = UNSET,
    x_api_key: Union[Unset, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/mercury/orders".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    if authorization is not UNSET:
        headers["authorization"] = authorization
    if x_api_key is not UNSET:
        headers["x-api-key"] = x_api_key

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[MercuryErrorResponse, MercuryListOrdersResponse]]:
    if response.status_code == 200:
        response_200 = MercuryListOrdersResponse.from_dict(response.json())

        return response_200
    if response.status_code == 400:
        response_400 = MercuryErrorResponse.from_dict(response.json())

        return response_400
    if response.status_code == 500:
        response_500 = MercuryErrorResponse.from_dict(response.json())

        return response_500
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[MercuryErrorResponse, MercuryListOrdersResponse]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: MercuryListOrdersRequest,
    authorization: Union[Unset, str] = UNSET,
    x_api_key: Union[Unset, str] = UNSET,
) -> Response[Union[MercuryErrorResponse, MercuryListOrdersResponse]]:
    kwargs = _get_kwargs(client=client, json_body=json_body, authorization=authorization, x_api_key=x_api_key,)

    response = httpx.post(verify=client.verify_ssl, **kwargs,)

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    json_body: MercuryListOrdersRequest,
    authorization: Union[Unset, str] = UNSET,
    x_api_key: Union[Unset, str] = UNSET,
) -> Optional[Union[MercuryErrorResponse, MercuryListOrdersResponse]]:
    """ Get a list of Assessment Orders by either job application ID and/or candidate ID. At least one of the IDs must be provided. """

    return sync_detailed(client=client, json_body=json_body, authorization=authorization, x_api_key=x_api_key,).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: MercuryListOrdersRequest,
    authorization: Union[Unset, str] = UNSET,
    x_api_key: Union[Unset, str] = UNSET,
) -> Response[Union[MercuryErrorResponse, MercuryListOrdersResponse]]:
    kwargs = _get_kwargs(client=client, json_body=json_body, authorization=authorization, x_api_key=x_api_key,)

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    json_body: MercuryListOrdersRequest,
    authorization: Union[Unset, str] = UNSET,
    x_api_key: Union[Unset, str] = UNSET,
) -> Optional[Union[MercuryErrorResponse, MercuryListOrdersResponse]]:
    """ Get a list of Assessment Orders by either job application ID and/or candidate ID. At least one of the IDs must be provided. """

    return (
        await asyncio_detailed(client=client, json_body=json_body, authorization=authorization, x_api_key=x_api_key,)
    ).parsed



""" Contains all the data models used in inputs/outputs """

from .assessment_type import AssessmentType
from .ats_type import AtsType
from .mercury_assessment import MercuryAssessment
from .mercury_assessment_order import MercuryAssessmentOrder
from .mercury_assessment_order_metadata import MercuryAssessmentOrderMetadata
from .mercury_candidate import MercuryCandidate
from .mercury_configuration import MercuryConfiguration
from .mercury_error_response import MercuryErrorResponse
from .mercury_list_orders_request import MercuryListOrdersRequest
from .mercury_list_orders_response import MercuryListOrdersResponse
from .mercury_order_create_response import MercuryOrderCreateResponse
from .mercury_order_request import MercuryOrderRequest
from .mercury_order_request_metadata import MercuryOrderRequestMetadata
from .mercury_report import MercuryReport
from .mercury_result import MercuryResult
from .o_auth_token_request import OAuthTokenRequest
from .o_auth_token_response import OAuthTokenResponse
from .pontem_order_statuses import PontemOrderStatuses



from enum import Enum


class AtsType(str, Enum):
    ADP = "adp"
    AVATURE = "avature"
    ICIMS = "icims"
    KENEXA = "kenexa"
    MERCURY_API = "mercury_api"
    CLIENT_PORTAL = "client_portal"
    OLEEO = "oleeo"
    ORC = "orc"
    SAP_SF = "sap_sf"
    WORKDAY = "workday"

    def __str__(self) -> str:
        return str(self.value)



import os

from pymetrics_assessment_api_client import Client
from pymetrics_assessment_api_client.api.default import \
    mercury_get_config, mercury_o_auth
from pymetrics_assessment_api_client.examples.constants import BASE_URL, \
    ENV_NAME_X_API_KEY, ENV_NAME_CLIENT_ID, ENV_NAME_CLIENT_SECRET
from pymetrics_assessment_api_client.models import OAuthTokenRequest, \
    OAuthTokenResponse, MercuryConfiguration
from pymetrics_assessment_api_client.types import Response


def main():

    client_id = os.getenv(ENV_NAME_CLIENT_ID)
    client_secret = os.getenv(ENV_NAME_CLIENT_SECRET)
    client = Client(base_url=BASE_URL)

    request = OAuthTokenRequest(client_id=client_id,
                                client_secret=client_secret,
                                grant_type="client_credentials")
    auth_response: Response = mercury_o_auth.sync_detailed(client=client,
                                                           json_body=request)

    oauth_response: OAuthTokenResponse = auth_response.parsed
    x_api_key = os.getenv(ENV_NAME_X_API_KEY)
    auth = f"Bearer {oauth_response.access_token}"

    get_config_response: Response = mercury_get_config.sync_detailed(
        client=client,
        authorization=auth,
        x_api_key=x_api_key
    )
    parsed_get_config_response: MercuryConfiguration = get_config_response.parsed

    print(f"Successfully retrieved all assessments: {parsed_get_config_response.to_dict()}")


if __name__ == '__main__':
    main()




import os

from pymetrics_assessment_api_client import Client
from pymetrics_assessment_api_client.api.default import mercury_list_orders, \
    mercury_o_auth
from pymetrics_assessment_api_client.examples.constants import BASE_URL, \
    ENV_NAME_X_API_KEY, ENV_NAME_CLIENT_ID, ENV_NAME_CLIENT_SECRET, \
    CANDIDATE_ID, JOB_APPLICATION_ID
from pymetrics_assessment_api_client.models import OAuthTokenRequest, \
    OAuthTokenResponse, MercuryListOrdersRequest, \
    MercuryListOrdersResponse
from pymetrics_assessment_api_client.types import Response


def main():

    client_id = os.getenv(ENV_NAME_CLIENT_ID)
    client_secret = os.getenv(ENV_NAME_CLIENT_SECRET)
    client = Client(base_url=BASE_URL)

    request = OAuthTokenRequest(client_id=client_id,
                                client_secret=client_secret,
                                grant_type="client_credentials")
    auth_response: Response = mercury_o_auth.sync_detailed(client=client,
                                                           json_body=request)

    oauth_response: OAuthTokenResponse = auth_response.parsed
    x_api_key = os.getenv(ENV_NAME_X_API_KEY)
    auth = f"Bearer {oauth_response.access_token}"

    list_orders_request_by_candidate_id = MercuryListOrdersRequest(
        candidate_id=CANDIDATE_ID
    )

    list_orders_response_cand: Response = mercury_list_orders.sync_detailed(
        client=client,
        json_body=list_orders_request_by_candidate_id,
        x_api_key=x_api_key,
        authorization=auth
    )
    parsed_list_orders_response_cand: MercuryListOrdersResponse = list_orders_response_cand.parsed

    print(f"Successfully listed order(s) by candidate id: {parsed_list_orders_response_cand.to_dict()}")


    list_orders_request_by_job_id = MercuryListOrdersRequest(
        job_application_id=JOB_APPLICATION_ID
    )

    list_orders_response_job: Response = mercury_list_orders.sync_detailed(
        client=client,
        json_body=list_orders_request_by_job_id,
        x_api_key=x_api_key,
        authorization=auth
    )
    parsed_list_orders_response_job: MercuryListOrdersResponse = \
        list_orders_response_job.parsed

    print(
        f"Successfully listed order(s) by job application id: "
        f"{parsed_list_orders_response_job.to_dict()}")




if __name__ == '__main__':
    main()




import os

from pymetrics_assessment_api_client import Client
from pymetrics_assessment_api_client.examples.constants import BASE_URL, \
    ENV_NAME_X_API_KEY, ENV_NAME_CLIENT_ID, ENV_NAME_CLIENT_SECRET, \
    ASSESSMENT_ID
from pymetrics_assessment_api_client.models import MercuryAssessmentOrder, \
    OAuthTokenRequest, OAuthTokenResponse, MercuryCandidate, \
    MercuryOrderRequest, MercuryAssessmentOrderMetadata, \
    MercuryOrderCreateResponse
from pymetrics_assessment_api_client.api.default import mercury_retrieve_order, \
    mercury_o_auth, mercury_create_order

from pymetrics_assessment_api_client.types import Response


def main():

    client_id = os.getenv(ENV_NAME_CLIENT_ID)
    client_secret = os.getenv(ENV_NAME_CLIENT_SECRET)
    client = Client(base_url=BASE_URL)

    request = OAuthTokenRequest(client_id=client_id,
                                client_secret=client_secret,
                                grant_type="client_credentials")
    auth_response: Response = mercury_o_auth.sync_detailed(client=client,
                                                           json_body=request)

    oauth_response: OAuthTokenResponse = auth_response.parsed
    x_api_key = os.getenv(ENV_NAME_X_API_KEY)
    auth = f"Bearer {oauth_response.access_token}"

    candidate = MercuryCandidate(
        email="test@example.com",
        first_name="Test",
        last_name="Example",
        external_id="test_example"
    )

    meta_data = MercuryAssessmentOrderMetadata()
    meta_data.additional_properties = {"job_name": "accountant"}

    order_request = MercuryOrderRequest(
        candidate=candidate,
        assessment_id=ASSESSMENT_ID,
        application_id="test_example_002",
        metadata=meta_data
    )

    create_order_response: Response = mercury_create_order.sync_detailed(
        client=client,
        json_body=order_request,
        x_api_key=x_api_key,
        authorization=auth
    )
    parsed_create_order_response: MercuryOrderCreateResponse = create_order_response.parsed

    order_uuid = parsed_create_order_response.order.id

    get_order_response: Response = mercury_retrieve_order.sync_detailed(
        client=client,
        uuid=order_uuid,
        authorization=auth,
        x_api_key=x_api_key,
        report=False
    )
    parsed_get_order_response: MercuryAssessmentOrder = get_order_response.parsed

    print(f"Successfully retrieved order: {parsed_get_order_response.to_dict()}")


if __name__ == '__main__':
    main()




BASE_URL = "https://staging.api.pymetrics.com"

ENV_NAME_CLIENT_ID = "MERCURY_CLIENT_ID"
ENV_NAME_CLIENT_SECRET = "MERCURY_CLIENT_SECRET"
ENV_NAME_X_API_KEY = "MERCURY_X_API_KEY"
ASSESSMENT_ID = "[INSERT ASSESSMENT UUID HERE]"
ORDER_UUID = "[INSERT ORDER UUID HERE]"
CANDIDATE_ID = "[INSERT CANDIDATE ID HERE]"
JOB_APPLICATION_ID = "[INSERT JOB APPLICATION ID HERE]"



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="OAuthTokenRequest")


@attr.s(auto_attribs=True)
class OAuthTokenRequest:
    """  """

    client_id: str
    client_secret: str
    grant_type: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        client_id = self.client_id
        client_secret = self.client_secret
        grant_type = self.grant_type

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {"client_id": client_id, "client_secret": client_secret, "grant_type": grant_type,}
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        client_id = d.pop("client_id")

        client_secret = d.pop("client_secret")

        grant_type = d.pop("grant_type")

        o_auth_token_request = cls(client_id=client_id, client_secret=client_secret, grant_type=grant_type,)

        o_auth_token_request.additional_properties = d
        return o_auth_token_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import os

from pymetrics_assessment_api_client import Client
from pymetrics_assessment_api_client.api.default import \
    mercury_retrieve_order, \
    mercury_o_auth
from pymetrics_assessment_api_client.examples.constants import BASE_URL, \
    ENV_NAME_X_API_KEY, ENV_NAME_CLIENT_ID, ENV_NAME_CLIENT_SECRET, ORDER_UUID
from pymetrics_assessment_api_client.models import MercuryAssessmentOrder, \
    OAuthTokenRequest, OAuthTokenResponse
from pymetrics_assessment_api_client.types import Response


def main():

    client_id = os.getenv(ENV_NAME_CLIENT_ID)
    client_secret = os.getenv(ENV_NAME_CLIENT_SECRET)
    client = Client(base_url=BASE_URL)

    request = OAuthTokenRequest(client_id=client_id,
                                client_secret=client_secret,
                                grant_type="client_credentials")
    auth_response: Response = mercury_o_auth.sync_detailed(client=client,
                                                           json_body=request)

    oauth_response: OAuthTokenResponse = auth_response.parsed
    x_api_key = os.getenv(ENV_NAME_X_API_KEY)
    auth = f"Bearer {oauth_response.access_token}"

    order_uuid = ORDER_UUID

    get_order_response: Response = mercury_retrieve_order.sync_detailed(
        client=client,
        uuid=order_uuid,
        authorization=auth,
        x_api_key=x_api_key,
        report=False
    )
    parsed_get_order_response: MercuryAssessmentOrder = get_order_response.parsed

    print(f"Successfully retrieved order: {parsed_get_order_response.to_dict()}")


if __name__ == '__main__':
    main()




# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pymetrics_assessment_api_client',
 'pymetrics_assessment_api_client.api',
 'pymetrics_assessment_api_client.api.default',
 'pymetrics_assessment_api_client.examples',
 'pymetrics_assessment_api_client.models']

package_data = \
{'': ['*']}

install_requires = \
['attrs>=20.1.0,<22.0.0',
 'httpx>=0.15.4,<0.21.0',
 'python-dateutil>=2.8.0,<3.0.0']

setup_kwargs = {
    'name': 'pymetrics-assessment-api-client',
    'version': '1.0.0',
    'description': 'A client library for accessing pymetrics Assessment API',
    'long_description': '# pymetrics-assessment-api-client\nA client library for accessing pymetrics Assessment API\n\n## Installation\n\n```bash\npip install pymetrics-assessment-api-client\n```\n\n## Usage\n\nA full set of examples can be found in the [pymetrics-assessments-api-client examples directory](https://github.com/pymetrics/pymetrics_assessment_api_client/tree/main/pymetrics_assessment_api_client/examples).\n\nTo get started, please request Client ID, Client Secret and API Key from pymetrics.\n\nFirst, create a client for staging environment:\n\n```python\nfrom pymetrics_assessment_api_client import Client\n\nclient = Client(base_url="https://staging.pymetrics.com")\n```\n\nTo get an authenticated token, you can hit the get oauth endpoint by doing the following:\n```python\nfrom pymetrics_assessment_api_client.models import OAuthTokenRequest\nfrom pymetrics_assessment_api_client.api.default import mercury_o_auth\nfrom pymetrics_assessment_api_client.models import OAuthTokenResponse\nfrom pymetrics_assessment_api_client.types import Response\n\nrequest = OAuthTokenRequest(client_id=client_id,\n                            client_secret=client_secret,\n                            grant_type="client_credentials")\nauth_response: Response = mercury_o_auth.sync_detailed(client=client,\n                                                       json_body=request)\nauth_token_response: OAuthTokenResponse = auth_response.parsed\nprint(f"Access Token: {auth_token_response.access_token}")\n```\nTo retrieve an order, you can use the token generated above and hit the get order endpoint:\n```python\nfrom pymetrics_assessment_api_client.api.default import mercury_retrieve_order\nfrom pymetrics_assessment_api_client.models import MercuryAssessmentOrder\nfrom pymetrics_assessment_api_client.types import Response\n\nauth = f"Bearer {access_token}"\n\nget_order_response: Response = mercury_retrieve_order.sync_detailed(\n    client=client,\n    uuid=order_uuid,\n    authorization=auth,\n    x_api_key=API_KEY,\n    report=False\n)\nparsed_get_order_response: MercuryAssessmentOrder = get_order_response.parsed\nprint(f"Successfully retrieved order: {parsed_get_order_response.to_dict()}")\n```\n\n## Base URLs\nUS Production: https://www.pymetrics.com\n\nUS Staging: https://staging.pymetrics.com',
    'author': 'Michelle Tsai',
    'author_email': 'min.tsai@pymetrics.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



from enum import Enum


class PontemOrderStatuses(str, Enum):
    REJECTED = "Rejected"
    PENDING = "Pending"
    ACCEPTED = "Accepted"
    NOT_STARTED = "Not Started"
    IN_PROGRESS = "In Progress"
    COMPLETED = "Completed"
    FULFILLED = "Fulfilled"
    EXPIRED = "Expired"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.mercury_candidate import MercuryCandidate
from ..models.mercury_order_request_metadata import MercuryOrderRequestMetadata
from ..types import UNSET, Unset

T = TypeVar("T", bound="MercuryOrderRequest")


@attr.s(auto_attribs=True)
class MercuryOrderRequest:
    """  """

    candidate: MercuryCandidate
    assessment_id: str
    application_id: str
    send_email: Union[Unset, bool] = False
    requisition_id: Union[Unset, str] = UNSET
    requisition_title: Union[Unset, str] = UNSET
    metadata: Union[Unset, MercuryOrderRequestMetadata] = UNSET
    candidate_redirect_url: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        candidate = self.candidate.to_dict()

        assessment_id = self.assessment_id
        application_id = self.application_id
        send_email = self.send_email
        requisition_id = self.requisition_id
        requisition_title = self.requisition_title
        metadata: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        candidate_redirect_url = self.candidate_redirect_url

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {"candidate": candidate, "assessment_id": assessment_id, "application_id": application_id,}
        )
        if send_email is not UNSET:
            field_dict["send_email"] = send_email
        if requisition_id is not UNSET:
            field_dict["requisition_id"] = requisition_id
        if requisition_title is not UNSET:
            field_dict["requisition_title"] = requisition_title
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if candidate_redirect_url is not UNSET:
            field_dict["candidate_redirect_url"] = candidate_redirect_url

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        candidate = MercuryCandidate.from_dict(d.pop("candidate"))

        assessment_id = d.pop("assessment_id")

        application_id = d.pop("application_id")

        send_email = d.pop("send_email", UNSET)

        requisition_id = d.pop("requisition_id", UNSET)

        requisition_title = d.pop("requisition_title", UNSET)

        _metadata = d.pop("metadata", UNSET)
        metadata: Union[Unset, MercuryOrderRequestMetadata]
        if isinstance(_metadata, Unset):
            metadata = UNSET
        else:
            metadata = MercuryOrderRequestMetadata.from_dict(_metadata)

        candidate_redirect_url = d.pop("candidate_redirect_url", UNSET)

        mercury_order_request = cls(
            candidate=candidate,
            assessment_id=assessment_id,
            application_id=application_id,
            send_email=send_email,
            requisition_id=requisition_id,
            requisition_title=requisition_title,
            metadata=metadata,
            candidate_redirect_url=candidate_redirect_url,
        )

        mercury_order_request.additional_properties = d
        return mercury_order_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import os

from pymetrics_assessment_api_client import Client
from pymetrics_assessment_api_client.examples.constants import BASE_URL, \
    ENV_NAME_CLIENT_ID, ENV_NAME_CLIENT_SECRET
from pymetrics_assessment_api_client.models import OAuthTokenRequest, \
    MercuryErrorResponse
from pymetrics_assessment_api_client.api.default import mercury_o_auth
from pymetrics_assessment_api_client.models import OAuthTokenResponse
from pymetrics_assessment_api_client.types import Response


def main():
    client_id = os.getenv(ENV_NAME_CLIENT_ID)
    client_secret = os.getenv(ENV_NAME_CLIENT_SECRET)
    client = Client(base_url=BASE_URL)
    request = OAuthTokenRequest(client_id=client_id,
                                client_secret=client_secret,
                                grant_type="client_credentials")
    auth_response: Response = mercury_o_auth.sync_detailed(client=client,
                                                           json_body=request)
    if isinstance(auth_response.parsed, OAuthTokenResponse):
        auth_token_response = auth_response.parsed
        print(f"Access Token: {auth_token_response.access_token}")
    elif isinstance(auth_response.parsed, MercuryErrorResponse):
        error_response = auth_response.parsed
        print(f"Exception getting OAuth Token: {error_response.message}")


if __name__ == '__main__':
    main()




from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.mercury_configuration import MercuryConfiguration
from ...models.mercury_error_response import MercuryErrorResponse
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *, client: Client, authorization: Union[Unset, str] = UNSET, x_api_key: Union[Unset, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/mercury/configuration".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    if authorization is not UNSET:
        headers["authorization"] = authorization
    if x_api_key is not UNSET:
        headers["x-api-key"] = x_api_key

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[MercuryConfiguration, MercuryErrorResponse]]:
    if response.status_code == 200:
        response_200 = MercuryConfiguration.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = MercuryErrorResponse.from_dict(response.json())

        return response_401
    if response.status_code == 500:
        response_500 = MercuryErrorResponse.from_dict(response.json())

        return response_500
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[MercuryConfiguration, MercuryErrorResponse]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *, client: Client, authorization: Union[Unset, str] = UNSET, x_api_key: Union[Unset, str] = UNSET,
) -> Response[Union[MercuryConfiguration, MercuryErrorResponse]]:
    kwargs = _get_kwargs(client=client, authorization=authorization, x_api_key=x_api_key,)

    response = httpx.get(verify=client.verify_ssl, **kwargs,)

    return _build_response(response=response)


def sync(
    *, client: Client, authorization: Union[Unset, str] = UNSET, x_api_key: Union[Unset, str] = UNSET,
) -> Optional[Union[MercuryConfiguration, MercuryErrorResponse]]:
    """ Lists the assessment templates that are currently registered for your integration.
These are configured outside of the API, and represent the different candidate experiences
for each role pymetrics is being leveraged for.
 """

    return sync_detailed(client=client, authorization=authorization, x_api_key=x_api_key,).parsed


async def asyncio_detailed(
    *, client: Client, authorization: Union[Unset, str] = UNSET, x_api_key: Union[Unset, str] = UNSET,
) -> Response[Union[MercuryConfiguration, MercuryErrorResponse]]:
    kwargs = _get_kwargs(client=client, authorization=authorization, x_api_key=x_api_key,)

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *, client: Client, authorization: Union[Unset, str] = UNSET, x_api_key: Union[Unset, str] = UNSET,
) -> Optional[Union[MercuryConfiguration, MercuryErrorResponse]]:
    """ Lists the assessment templates that are currently registered for your integration.
These are configured outside of the API, and represent the different candidate experiences
for each role pymetrics is being leveraged for.
 """

    return (await asyncio_detailed(client=client, authorization=authorization, x_api_key=x_api_key,)).parsed



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.ats_type import AtsType
from ..models.mercury_assessment import MercuryAssessment
from ..models.mercury_assessment_order_metadata import MercuryAssessmentOrderMetadata
from ..models.mercury_candidate import MercuryCandidate
from ..models.mercury_report import MercuryReport
from ..models.mercury_result import MercuryResult
from ..models.pontem_order_statuses import PontemOrderStatuses
from ..types import UNSET, Unset

T = TypeVar("T", bound="MercuryAssessmentOrder")


@attr.s(auto_attribs=True)
class MercuryAssessmentOrder:
    """  """

    id: str
    invite_link: str
    status: PontemOrderStatuses
    create_date: datetime.datetime
    candidate: MercuryCandidate
    assessment_id: str
    assessment: MercuryAssessment
    application_id: str
    ats_type: AtsType
    requisition_id: Union[Unset, str] = UNSET
    requisition_title: Union[Unset, str] = UNSET
    metadata: Union[Unset, MercuryAssessmentOrderMetadata] = UNSET
    recruiter_report: Union[Unset, str] = UNSET
    results: Union[Unset, List[MercuryResult]] = UNSET
    reports: Union[Unset, List[MercuryReport]] = UNSET
    candidate_redirect_url: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        invite_link = self.invite_link
        status = self.status.value

        create_date = self.create_date.isoformat()

        candidate = self.candidate.to_dict()

        assessment_id = self.assessment_id
        assessment = self.assessment.to_dict()

        application_id = self.application_id
        ats_type = self.ats_type.value

        requisition_id = self.requisition_id
        requisition_title = self.requisition_title
        metadata: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        recruiter_report = self.recruiter_report
        results: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.results, Unset):
            results = []
            for results_item_data in self.results:
                results_item = results_item_data.to_dict()

                results.append(results_item)

        reports: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.reports, Unset):
            reports = []
            for reports_item_data in self.reports:
                reports_item = reports_item_data.to_dict()

                reports.append(reports_item)

        candidate_redirect_url = self.candidate_redirect_url

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "invite_link": invite_link,
                "status": status,
                "create_date": create_date,
                "candidate": candidate,
                "assessment_id": assessment_id,
                "assessment": assessment,
                "application_id": application_id,
                "ats_type": ats_type,
            }
        )
        if requisition_id is not UNSET:
            field_dict["requisition_id"] = requisition_id
        if requisition_title is not UNSET:
            field_dict["requisition_title"] = requisition_title
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if recruiter_report is not UNSET:
            field_dict["recruiter_report"] = recruiter_report
        if results is not UNSET:
            field_dict["results"] = results
        if reports is not UNSET:
            field_dict["reports"] = reports
        if candidate_redirect_url is not UNSET:
            field_dict["candidate_redirect_url"] = candidate_redirect_url

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        invite_link = d.pop("invite_link")

        status = PontemOrderStatuses(d.pop("status"))

        create_date = isoparse(d.pop("create_date"))

        candidate = MercuryCandidate.from_dict(d.pop("candidate"))

        assessment_id = d.pop("assessment_id")

        assessment = MercuryAssessment.from_dict(d.pop("assessment"))

        application_id = d.pop("application_id")

        ats_type = AtsType(d.pop("ats_type"))

        requisition_id = d.pop("requisition_id", UNSET)

        requisition_title = d.pop("requisition_title", UNSET)

        _metadata = d.pop("metadata", UNSET)
        metadata: Union[Unset, MercuryAssessmentOrderMetadata]
        if isinstance(_metadata, Unset) or _metadata is None:
            metadata = UNSET
        else:
            metadata = MercuryAssessmentOrderMetadata.from_dict(_metadata)

        recruiter_report = d.pop("recruiter_report", UNSET)

        results = []
        _results = d.pop("results", UNSET)
        for results_item_data in _results or []:
            results_item = MercuryResult.from_dict(results_item_data)

            results.append(results_item)

        reports = []
        _reports = d.pop("reports", UNSET)
        for reports_item_data in _reports or []:
            reports_item = MercuryReport.from_dict(reports_item_data)

            reports.append(reports_item)

        candidate_redirect_url = d.pop("candidate_redirect_url", UNSET)

        mercury_assessment_order = cls(
            id=id,
            invite_link=invite_link,
            status=status,
            create_date=create_date,
            candidate=candidate,
            assessment_id=assessment_id,
            assessment=assessment,
            application_id=application_id,
            ats_type=ats_type,
            requisition_id=requisition_id,
            requisition_title=requisition_title,
            metadata=metadata,
            recruiter_report=recruiter_report,
            results=results,
            reports=reports,
            candidate_redirect_url=candidate_redirect_url,
        )

        mercury_assessment_order.additional_properties = d
        return mercury_assessment_order

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.assessment_type import AssessmentType

T = TypeVar("T", bound="MercuryAssessment")


@attr.s(auto_attribs=True)
class MercuryAssessment:
    """  """

    id: str
    type: AssessmentType
    description: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        type = self.type.value

        description = self.description

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {"id": id, "type": type, "description": description,}
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        type = AssessmentType(d.pop("type"))

        description = d.pop("description")

        mercury_assessment = cls(id=id, type=type, description=description,)

        mercury_assessment.additional_properties = d
        return mercury_assessment

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
